@@ -12,25 +12,27 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from diskimage_builder.block_device.blockdevicesetupexception \
-    import BlockDeviceSetupException
-from diskimage_builder.block_device.plugin_base import NodePluginBase
-from diskimage_builder.block_device.utils import parse_abs_size_spec
-from diskimage_builder.graph.digraph import Digraph
 import logging
 import os
 import subprocess
 
+from diskimage_builder.block_device.exception import \
+    BlockDeviceSetupException
+from diskimage_builder.block_device.tree_config import TreeConfig
+from diskimage_builder.block_device.utils import parse_abs_size_spec
+from diskimage_builder.graph.digraph import Digraph
+
 
 logger = logging.getLogger(__name__)
 
 
-class LocalLoop(NodePluginBase):
+class LocalLoop(Digraph.Node):
     """Level0: Local loop image device handling.
 
     This class handles local loop devices that can be used
     for VM image installation.
     """
+    tree_config = TreeConfig("local_loop")
 
     def __init__(self, config, default_config):
         logger.debug("Creating LocalLoop object; config [%s] "
@@ -39,12 +41,12 @@ class LocalLoop(NodePluginBase):
             self.size = parse_abs_size_spec(config['size'])
             logger.debug("Image size [%s]" % self.size)
         else:
-            self.size = parse_abs_size_spec(default_config['image_size'])
+            self.size = parse_abs_size_spec(default_config['image-size'])
             logger.debug("Using default image size [%s]" % self.size)
         if 'directory' in config:
             self.image_dir = config['directory']
         else:
-            self.image_dir = default_config['image_dir']
+            self.image_dir = default_config['image-dir']
         self.name = config['name']
         Digraph.Node.__init__(self, self.name)
         self.filename = os.path.join(self.image_dir, self.name + ".raw")
@@ -53,6 +55,10 @@ class LocalLoop(NodePluginBase):
         """Because this is created without base, there are no edges."""
         pass
 
+    def insert_nodes(self, dg):
+        """Adds self as a node to the given digraph"""
+        dg.add_node(self)
+
     @staticmethod
     def image_create(filename, size):
         logger.info("Create image file [%s]" % filename)
@@ -111,17 +117,20 @@ class LocalLoop(NodePluginBase):
         block_device = self._loopdev_attach(self.filename)
         rollback.append(lambda: self._loopdev_detach(block_device))
 
-        result[self.name] = {"device": block_device,
-                             "image": self.filename}
+        if 'blockdev' not in result:
+            result['blockdev'] = {}
+
+        result['blockdev'][self.name] = {"device": block_device,
+                                         "image": self.filename}
         logger.debug("Created loop  name [%s] device [%s] image [%s]"
                      % (self.name, block_device, self.filename))
         return
 
     def umount(self, state):
-        self._loopdev_detach(state[self.name]['device'])
+        self._loopdev_detach(state['blockdev'][self.name]['device'])
 
     def cleanup(self, state):
         pass
 
     def delete(self, state):
-        self._image_delete(state[self.name]['image'])
+        self._image_delete(state['blockdev'][self.name]['image'])
